Package 'nzilbb.labbcat'

Title: Accessing Data Stored in 'LaBB-CAT' Instances
Description: 'LaBB-CAT' is a web-based language corpus management system developed by the New Zealand Institute of Language, Brain and Behaviour (NZILBB) - see <https://labbcat.canterbury.ac.nz>. This package defines functions for accessing corpus data in a 'LaBB-CAT' instance. You must have at least version 20230818.1400 of 'LaBB-CAT' to use this package. For more information about 'LaBB-CAT', see Robert Fromont and Jennifer Hay (2008) <doi:10.3366/E1749503208000142> or Robert Fromont (2017) <doi:10.1016/j.csl.2017.01.004>.
Authors: Robert Fromont [aut, cre] (ORCID: <https://orcid.org/0000-0001-5271-5487>)
Maintainer: Robert Fromont <[email protected]>
License: GPL (>= 3)
Version: 1.5-1
Built: 2026-05-23 09:37:05 UTC
Source: https://github.com/nzilbb/labbcat-r

Help Index